.\" Copyright (c) 2001-2003 The Open Group, All Rights Reserved 
.TH "NL_LANGINFO" P 2003 "IEEE/The Open Group" "POSIX Programmer's Manual"
.\" nl_langinfo 
.SH NAME
nl_langinfo \- language information
.SH SYNOPSIS
.LP
\fB#include <langinfo.h>
.br
.sp
char *nl_langinfo(nl_item\fP \fIitem\fP\fB); \fP
\fB
.br
\fP
.SH DESCRIPTION
.LP
The \fInl_langinfo\fP() function shall return a pointer to a string
containing information relevant to the particular language
or cultural area defined in the program's locale (see \fI<langinfo.h>\fP).
The
manifest constant names and values of \fIitem\fP are defined in \fI<langinfo.h>\fP.
For example:
.sp
.RS
.nf

\fBnl_langinfo(ABDAY_1)
\fP
.fi
.RE
.LP
would return a pointer to the string \fB"Dom"\fP if the identified
language was Portuguese, and \fB"Sun"\fP if the
identified language was English.
.LP
Calls to \fIsetlocale\fP() with a category corresponding to the category
of
\fIitem\fP (see \fI<langinfo.h>\fP), or to the category \fILC_ALL
,\fP may
overwrite the array pointed to by the return value.
.LP
The \fInl_langinfo\fP() function need not be reentrant. A function
that is not required to be reentrant is not required to be
thread-safe.
.SH RETURN VALUE
.LP
In a locale where \fIlanginfo\fP data is not defined, \fInl_langinfo\fP()
shall return a pointer to the corresponding string
in the POSIX locale. In all locales, \fInl_langinfo\fP() shall return
a pointer to an empty string if \fIitem\fP contains an
invalid setting.
.LP
This pointer may point to static data that may be overwritten on the
next call.
.SH ERRORS
.LP
No errors are defined.
.LP
\fIThe following sections are informative.\fP
.SH EXAMPLES
.SS Getting Date and Time Formatting Information
.LP
The following example returns a pointer to a string containing date
and time formatting information, as defined in the
\fILC_TIME\fP category of the current locale.
.sp
.RS
.nf

\fB#include <time.h>
#include <langinfo.h>
\&...
strftime(datestring, sizeof(datestring), nl_langinfo(D_T_FMT), tm);
\&...
\fP
.fi
.RE
.SH APPLICATION USAGE
.LP
The array pointed to by the return value should not be modified by
the program, but may be modified by further calls to
\fInl_langinfo\fP().
.SH RATIONALE
.LP
None.
.SH FUTURE DIRECTIONS
.LP
None.
.SH SEE ALSO
.LP
\fIsetlocale\fP() , the Base Definitions volume of IEEE\ Std\ 1003.1-2001,
Chapter 7, Locale, \fI<langinfo.h>\fP, \fI<nl_types.h>\fP
.SH COPYRIGHT
Portions of this text are reprinted and reproduced in electronic form
from IEEE Std 1003.1, 2003 Edition, Standard for Information Technology
-- Portable Operating System Interface (POSIX), The Open Group Base
Specifications Issue 6, Copyright (C) 2001-2003 by the Institute of
Electrical and Electronics Engineers, Inc and The Open Group. In the
event of any discrepancy between this version and the original IEEE and
The Open Group Standard, the original IEEE and The Open Group Standard
is the referee document. The original Standard can be obtained online at
http://www.opengroup.org/unix/online.html .
